@@ -25,6 +25,7 @@ from twisted.internet.error import TimeoutError
 from twisted.internet.error import DNSLookupError
 from twisted.internet.error import ConnectError
 from twisted.internet.error import NoRouteError
+from twisted.internet.error import ConnectionRefusedError
 from twisted.web.client import ResponseNeverReceived
 from twisted.web.client import ResponseFailed
 from twisted.web.error import SchemeNotSupported
@@ -43,7 +44,7 @@ class HTTPError(Exception):
         self.response = response
 
 
-_http_errors = (HTTPError, DNSLookupError, NoRouteError,
+_http_errors = (HTTPError, DNSLookupError, NoRouteError, ConnectionRefusedError,
                 TimeoutError, ConnectError, ResponseNeverReceived)
 
 
@@ -304,7 +305,8 @@ class HttpClientMixin(NodeBusyMixin, NodeLoggingMixin, BaseMixin):
 
     def _http_error_handler(self, failure, url=None):
         self.log.failure("HTTP Connection Failure to {url} : ", failure=failure, url=url)
-        failure.trap(HTTPError, DNSLookupError, ResponseNeverReceived, SchemeNotSupported)
+        failure.trap(HTTPError, DNSLookupError, ResponseNeverReceived,
+                     SchemeNotSupported, ConnectionRefusedError)
         if isinstance(failure.value, HTTPError):
             self.log.warn(
                 "Encountered error {e} while trying to {method} {url}",
@@ -331,6 +333,11 @@ class HttpClientMixin(NodeBusyMixin, NodeLoggingMixin, BaseMixin):
                 "Got an unsupported scheme for {url}. Check your URL and "
                 "try again.", url=url
             )
+        if isinstance(failure.value, ConnectionRefusedError):
+            self.log.warn(
+                "Server seems to be unavailable for {url}. Check URL and "
+                "server readiness and try again", url=url
+            )
         return failure
 
     def _http_check_response(self, response):
